Enum safe_token_swap::error::SwapError
source · [−]pub enum SwapError {
Show 29 variants
AlreadyInUse,
InvalidProgramAddress,
InvalidOwner,
InvalidOutputOwner,
ExpectedMint,
ExpectedAccount,
EmptySupply,
InvalidSupply,
InvalidDelegate,
InvalidInput,
IncorrectSwapAccount,
IncorrectPoolMint,
InvalidOutput,
CalculationFailure,
InvalidInstruction,
RepeatedMint,
ExceededSlippage,
InvalidCloseAuthority,
InvalidFreezeAuthority,
IncorrectFeeAccount,
ZeroTradingTokens,
FeeCalculationFailure,
ConversionFailure,
InvalidFee,
IncorrectTokenProgramId,
UnsupportedCurveType,
InvalidCurve,
UnsupportedCurveOperation,
InvalidFeeAccount,
}Expand description
Errors that may be returned by the TokenSwap program.
Variants
AlreadyInUse
The account cannot be initialized because it is already being used.
InvalidProgramAddress
The program address provided doesn’t match the value generated by the program.
InvalidOwner
The owner of the input isn’t set to the program address generated by the program.
InvalidOutputOwner
The owner of the pool token output is set to the program address generated by the program.
ExpectedMint
The deserialization of the account returned something besides State::Mint.
ExpectedAccount
The deserialization of the account returned something besides State::Account.
EmptySupply
The input token account is empty.
InvalidSupply
The pool token mint has a non-zero supply.
InvalidDelegate
The provided token account has a delegate.
InvalidInput
The input token is invalid for swap.
IncorrectSwapAccount
Address of the provided swap token account is incorrect.
IncorrectPoolMint
Address of the provided pool token mint is incorrect
InvalidOutput
The output token is invalid for swap.
CalculationFailure
General calculation failure due to overflow or underflow
InvalidInstruction
Invalid instruction number passed in.
RepeatedMint
Swap input token accounts have the same mint
ExceededSlippage
Swap instruction exceeds desired slippage limit
InvalidCloseAuthority
The provided token account has a close authority.
InvalidFreezeAuthority
The pool token mint has a freeze authority.
IncorrectFeeAccount
The pool fee token account is incorrect
ZeroTradingTokens
Given pool token amount results in zero trading tokens
FeeCalculationFailure
The fee calculation failed due to overflow, underflow, or unexpected 0
ConversionFailure
ConversionFailure
InvalidFee
The provided fee does not match the program owner’s constraints
IncorrectTokenProgramId
The provided token program does not match the token program expected by the swap
UnsupportedCurveType
The provided curve type is not supported by the program owner
InvalidCurve
The provided curve parameters are invalid
UnsupportedCurveOperation
The operation cannot be performed on the given curve
InvalidFeeAccount
The pool fee account is invalid.