#[repr(C)]
pub struct WithdrawAllTokenTypes { pub pool_token_amount: u64, pub minimum_token_a_amount: u64, pub minimum_token_b_amount: u64, }
WithdrawAllTokenTypes instruction data

Fields

pool_token_amount: u64

Amount of pool tokens to burn. User receives an output of token a and b based on the percentage of the pool tokens that are returned.

minimum_token_a_amount: u64

Minimum amount of token A to receive, prevents excessive slippage

minimum_token_b_amount: u64

Minimum amount of token B to receive, prevents excessive slippage